# 3designs MCP Server

**Create awesome iOS experiences with SwiftUI** by juggling  UIX components, not coding.

# About

It is a SwiftUI-focused MCP that provides production-ready SwiftUI components and code snippets to help you create awesome iOS experiences.

Browse experiences in the gallery, select a design / animation / haptic and bring it into your app. Or create a new custom UIX from scratch.

Think 21st-dev tuned for iOS. Plus there is smth else completely awesome in wip.

When I started using it - i stopped writting SwiftUI code. Im just juggling components (whether that's good or bad).
My workflow with this MCP made me feel something like what @matt described in his blog post - [on symbolic to semantic leap in code understanding](https://nshipster.com/as-we-may-code/#future-applications-the-promise-of-what-lies-ahead)

Okay this page will be updated later. maybe.


## Installation and Usage

Installation instructions are exactly the same as for [DevBrain MCP](https://github.com/mimeCam/mcp-devbrain-stdio). Just use `3designs` instead of `devbrain` in product naming.


## License
This project is released under the MIT License and is developed by mimeCam as an open-source initiative.
